Enum Csr
#[repr(u8)]pub enum Csr {
Rollover = 0,
NotRollover = 1,
}Variants
Rollover = 0
Counters roll over to zero after reaching the maximum value
NotRollover = 1
Counters do not roll over to zero after reaching the maximum value
Implementations